Struct WpColorManagementOutputV1
pub struct WpColorManagementOutputV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
output color properties
A wp_color_management_output_v1 describes the color properties of an output.
The wp_color_management_output_v1 is associated with the wl_output global underlying the wl_output object. Therefore the client destroying the wl_output object has no impact, but the compositor removing the output global makes the wp_color_management_output_v1 object inert.
See also the Request enum for this interface.
Implementations
impl WpColorManagementOutputV1
impl WpColorManagementOutputV1
pub fn image_description_changed(&self)
pub fn image_description_changed(&self)
image description changed
This event is sent whenever the image description of the output changed, followed by one wl_output.done event common to output events across all extensions.
If the client wants to use the updated image description, it needs to do get_image_description again, because image description objects are immutable.