Enum Request
#[non_exhaustive]pub enum Request {
Destroy,
GetImageDescription {
image_description: New<WpImageDescriptionV1>,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy the color management output
Destroy the color wp_color_management_output_v1 object. This does not affect any remaining protocol objects.
This is a destructor, once received this object cannot be used any longer.
GetImageDescription
get the image description of the output
This creates a new wp_image_description_v1 object for the current image description of the output. There always is exactly one image description active for an output so the client should destroy the image description created by earlier invocations of this request. This request is usually sent as a reaction to the image_description_changed event or when creating a wp_color_management_output_v1 object.
The image description of an output represents the color encoding the output expects. There might be performance and power advantages, as well as improved color reproduction, if a content update matches the image description of the output it is being shown on. If a content update is shown on any other output than the one it matches the image description of, then the color reproduction on those outputs might be considerably worse.
The created wp_image_description_v1 object preserves the image description of the output from the time the object was created.
The resulting image description object allows get_information request.
If this protocol object is inert, the resulting image description object shall immediately deliver the wp_image_description_v1.failed event with the no_output cause.
If the interface version is inadequate for the output’s image description, meaning that the client does not support all the events needed to deliver the crucial information, the resulting image description object shall immediately deliver the wp_image_description_v1.failed event with the low_version cause.
Otherwise the object shall immediately deliver the ready event.
Fields
image_description: New<WpImageDescriptionV1>Implementations